;; Generated package description from leaf.el  -*- no-byte-compile: t -*-
(define-package "leaf" "4.5.5.0.20211226.163340" "Simplify your init.el configuration, extended use-package" '((emacs "24.1")) :commit "9eb18e8c9c375aa0158fbd06ea906bfbf54408fe" :authors '(("Naoya Yamashita" . "conao3@gmail.com")) :maintainer '("Naoya Yamashita" . "conao3@gmail.com") :keywords '("lisp" "settings") :url "https://github.com/conao3/leaf.el")
